@@ -1,13 +1,13 @@
-//! AGA8 calculations
+//! The AGA8 DETAIL equation of state.
 
-pub const NC_DETAIL: usize = 21;
+pub const NC: usize = 21;
 const MAXFLDS: usize = 21;
 const NTERMS: usize = 58;
 const EPSILON: f64 = 1e-15;
 const RDETAIL: f64 = 8.31451;
 
-/// Molar masses (g/mol)
-const MMI_DETAIL: [f64; 21] = [
+// Molar masses (g/mol)
+const MMI: [f64; 21] = [
     16.043,  // Methane
     28.0135, // Nitrogen
     44.01,   // Carbon dioxide
@@ -31,7 +31,7 @@ const MMI_DETAIL: [f64; 21] = [
     39.948,  // Argon
 ];
 
-/// Coefficients of the equation of state
+// Coefficients of the equation of state
 const AN: [f64; NTERMS] = [
     0.153_832_6,
     1.341_953_,
@@ -93,20 +93,20 @@ const AN: [f64; NTERMS] = [
     0.002_850_908,
 ];
 
-/// Density exponents
+// Density exponents
 const BN: [usize; NTERMS] = [
     1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3, 3, 3, 3,
     3, 3, 3, 3, 3, 4, 4, 4, 4, 4, 4, 4, 5, 5, 5, 5, 5, 6, 6, 7, 7, 8, 8, 8, 9, 9,
 ];
 
-/// Exponents on density in EXP[-cn*D^kn] part
-/// The cn part in this term is not included in this program since it is 1 when kn<>0][and 0 otherwise
+// Exponents on density in EXP[-cn*D^kn] part
+// The cn part in this term is not included in this program since it is 1 when kn<>0][and 0 otherwise
 const KN: [usize; NTERMS] = [
     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 3, 2, 2, 2, 4, 4, 0, 0, 2, 2, 2, 4, 4, 4, 4, 0, 1, 1, 2, 2,
     3, 3, 4, 4, 4, 0, 0, 2, 2, 2, 4, 4, 0, 2, 2, 4, 4, 0, 2, 0, 2, 1, 2, 2, 2, 2,
 ];
 
-/// Temperature exponents
+// Temperature exponents
 const UN: [f64; NTERMS] = [
     0.0, 0.5, 1.0, 3.5, -0.5, 4.5, 0.5, 7.5, 9.5, 6.0, 12.0, 12.5, -6.0, 2.0, 3.0, 2.0, 2.0, 11.0,
     -0.5, 0.5, 0.0, 4.0, 6.0, 21.0, 23.0, 22.0, -1.0, -0.5, 7.0, -1.0, 6.0, 4.0, 1.0, 9.0, -13.0,
@@ -114,7 +114,7 @@ const UN: [f64; NTERMS] = [
     7.0, 3.0, 0.0, 1.0, 0.0,
 ];
 
-/// Flags
+// Flags
 // fn[13] = 1; fn[27] = 1; fn[30] = 1; fn[35] = 1;
 const FN: [i32; NTERMS] = [
     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0,
@@ -147,7 +147,7 @@ const WN: [i32; NTERMS] = [
     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 ];
 
-/// Energy parameters
+// Energy parameters
 const EI: [f64; MAXFLDS] = [
     151.318_3,
     99.737_78,
@@ -171,7 +171,7 @@ const EI: [f64; MAXFLDS] = [
     2.610_111,
     119.629_9,
 ];
-/// Size parameters
+// Size parameters
 const KI: [f64; MAXFLDS] = [
     0.461_925_5,
     0.447_915_3,
@@ -196,14 +196,14 @@ const KI: [f64; MAXFLDS] = [
     0.421_655_1,
 ];
 
-/// Orientation parameters
+// Orientation parameters
 const GI: [f64; MAXFLDS] = [
     0.0, 0.027_815, 0.189_065, 0.079_3, 0.141_239, 0.256_692, 0.281_835, 0.332_267, 0.366_911,
     0.289_731, 0.337_542, 0.383_381, 0.427_354, 0.469_659, 0.034_369, 0.021, 0.038_953, 0.332_5,
     0.088_5, 0.0, 0.0,
 ];
 
-/// Quadrupole parameters
+// Quadrupole parameters
 const QI: [f64; MAXFLDS] = [
     0.0, 0.0, 0.69, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 1.067_75,
     0.633_276, 0.0, 0.0,
@@ -228,7 +228,7 @@ const WI: [f64; MAXFLDS] = [
     0.0, 0.0, 0.0,
 ];
 
-/// Energy parameters
+// Energy parameters
 const EIJ: [[f64; MAXFLDS]; MAXFLDS] = [
     [
         1.0, 0.97164, 0.960_644, 1.0, 0.994_635, 1.019_53, 0.989_844, 1.002_35, 0.999_268,
@@ -605,10 +605,11 @@ const TH0I: [[f64; 7]; MAXFLDS] = [
 
 /// Implements the DETAIL equation of state described in
 /// AGA Report No. 8, Part 1, Third Edition, April 2017.
+///
 /// # Example
 ///
 /// ```
-/// use aga8::Detail;
+/// use aga8::detail::Detail;
 ///
 /// let mut aga8_test: Detail = Detail::new();
 ///
@@ -644,62 +645,62 @@ const TH0I: [[f64; 7]; MAXFLDS] = [
 /// // Set temperature in K
 /// aga8_test.t = 400.0;
 /// // Run density_detail to calculate the density in mol/l
-/// aga8_test.density_detail();
+/// aga8_test.density();
 /// // Run properties_detail to calculate all of the
 /// // output properties mentioned below
-/// aga8_test.properties_detail();
+/// aga8_test.properties();
 ///
-/// assert!(f64::abs(12.807_924_036_488_01 - aga8_test.d) < 1.0e-10);
+/// assert!((12.807_924_036_488_01 - aga8_test.d).abs() < 1.0e-10);
 /// ```
 
 pub struct Detail {
-    /// Calculated in the Pressure subroutine,
-    /// but not included as an argument since it
-    /// is only used internally in the density algorithm.
+    // Calculated in the Pressure subroutine,
+    // but not included as an argument since it
+    // is only used internally in the density algorithm.
     dp_dd_save: f64,
 
-    /// Temperature (K)
+    /// Temperature in K
     pub t: f64,
-    /// Pressure (kPa)
+    /// Pressure in kPa
     pub p: f64,
-    /// Molar concentration (mol/l)
+    /// Molar concentration in mol/l
     pub d: f64,
     /// Compressibility factor
     pub z: f64,
-    /// Molar mass (g/mol)
+    /// Molar mass in g/mol
     pub mm: f64,
     /// First derivative of pressure with respect
-    /// to density at constant temperature [kPa/(mol/l)]
+    /// to density at constant temperature in kPa/(mol/l)
     pub dp_dd: f64,
     /// Second derivative of pressure with respect
-    /// to density at constant temperature [kPa/(mol/l)^2]
+    /// to density at constant temperature in kPa/(mol/l)^2
     pub d2p_dd2: f64,
     /// Second derivative of pressure with respect to
-    /// temperature and density [kPa/(mol/l)/K] (currently not calculated)
+    /// temperature and density in kPa/(mol/l)/K (currently not calculated)
     pub d2p_dtd: f64,
     /// First derivative of pressure with respect to
-    /// temperature at constant density (kPa/K)
+    /// temperature at constant density in kPa/K
     pub dp_dt: f64,
-    /// Internal energy (J/mol)
+    /// Internal energy in J/mol
     pub u: f64,
-    /// Enthalpy (J/mol)
+    /// Enthalpy in J/mol
     pub h: f64,
-    /// Entropy [J/(mol-K)]
+    /// Entropy in J/(mol-K)
     pub s: f64,
-    /// Isochoric heat capacity [J/(mol-K)]
+    /// Isochoric heat capacity in J/(mol-K)
     pub cv: f64,
-    /// Isobaric heat capacity [J/(mol-K)]
+    /// Isobaric heat capacity in J/(mol-K)
     pub cp: f64,
-    /// Speed of sound (m/s)
+    /// Speed of sound in m/s
     pub w: f64,
-    /// Gibbs energy (J/mol)
+    /// Gibbs energy in J/mol
     pub g: f64,
-    /// Joule-Thomson coefficient (K/kPa)
+    /// Joule-Thomson coefficient in K/kPa
     pub jt: f64,
     /// Isentropic Exponent
     pub kappa: f64,
-    /// Composition (mole fraction)
-    pub x: [f64; NC_DETAIL],
+    /// Composition mole fractions
+    pub x: [f64; NC],
 
     xold: [f64; MAXFLDS],
     told: f64,
@@ -722,7 +723,7 @@ impl Default for Detail {
     fn default() -> Self {
         Detail {
             dp_dd_save: 0.0,
-            x: [0.0; NC_DETAIL],
+            x: [0.0; NC],
             t: 0.0,
             p: 0.0,
             d: 0.0,
@@ -761,14 +762,12 @@ impl Default for Detail {
 }
 
 impl Detail {
+    /// Constructs a new Detail struct
     pub fn new() -> Self {
         Default::default()
     }
 
     /// Initialize all the constants and parameters in the DETAIL model.
-    ///
-    /// Some values are modified for calculations that do not depend
-    /// on [`t`], D, and x in order to speed up the program.
     pub fn setup(&mut self) {
         for i in 0..MAXFLDS {
             self.ki25[i] = KI[i].powf(2.5);
@@ -945,12 +944,12 @@ impl Detail {
                         bsnij = bsnij * WI[i] * WI[j];
                     }
                     self.bsnij2[i][j][n] = AN[n]
-                        * f64::powf(EIJ[i][j] * f64::sqrt(EI[i] * EI[j]), UN[n])
-                        * f64::powf(KI[i] * KI[j], 1.5)
+                        * (EIJ[i][j] * (EI[i] * EI[j]).sqrt()).powf(UN[n])
+                        * (KI[i] * KI[j]).powf(1.5)
                         * bsnij;
                 }
-                self.kij5[i][j] = (f64::powi(KIJ[i][j], 5) - 1.0) * self.ki25[i] * self.ki25[j];
-                self.uij5[i][j] = (f64::powi(UIJ[i][j], 5) - 1.0) * self.ei25[i] * self.ei25[j];
+                self.kij5[i][j] = (KIJ[i][j].powi(5) - 1.0) * self.ki25[i] * self.ki25[j];
+                self.uij5[i][j] = (UIJ[i][j].powi(5) - 1.0) * self.ei25[i] * self.ei25[j];
                 self.gij5[i][j] = (GIJ[i][j] - 1.0) * (GI[i] + GI[j]) / 2.0;
             }
         }
@@ -959,65 +958,59 @@ impl Detail {
         const D0: f64 = 101.325 / RDETAIL / 298.15;
 
         for i in 0..MAXFLDS {
-            self.n0i[i][2] = self.n0i[i][2] - 1.0;
-            self.n0i[i][0] = self.n0i[i][0] - f64::ln(D0);
+            self.n0i[i][2] -= 1.0;
+            self.n0i[i][0] -= D0.ln();
         }
     }
 
-    /// Calculate molar mass of the mixture with the compositions
-    /// contained in the x() input array
+    /// Calculates molar mass of the gas composition
+    ///
     /// ## Returns:
     /// - mm - Molar mass (g/mol)
-    pub fn molar_mass_detail(&mut self) -> f64 {
+    pub fn molar_mass(&mut self) -> f64 {
         let mut mm = 0.0;
-        for (i, item) in MMI_DETAIL.iter().enumerate() {
+        for (i, item) in MMI.iter().enumerate() {
             mm += self.x[i] * item;
         }
         self.mm = mm;
         mm
     }
 
-    /// Calculate terms dependent only on composition
+    // Calculate terms dependent only on composition
     fn x_terms(&mut self) {
-        let mut g: f64;
-        let mut q: f64;
-        let mut f: f64;
-        let mut u: f64;
-        let q2: f64;
         let mut xij: f64;
         let mut xi2: f64;
-        let mut icheck: i32;
 
         // Check to see if a component fraction has changed.  If x is the same as the previous call, then exit.
-        icheck = 0;
+        let mut icheck = 0;
 
-        for i in 0..NC_DETAIL {
-            if f64::abs(self.x[i] - self.xold[i]) > 0.000_000_1 {
+        for (i, x) in self.x.iter().enumerate() {
+            if (x - self.xold[i]).abs() > 0.000_000_1 {
                 icheck = 1;
             }
-            self.xold[i] = self.x[i];
+            self.xold[i] = *x;
         }
         if icheck == 0 {
             return;
         }
 
         self.k3 = 0.0;
-        u = 0.0;
-        g = 0.0;
-        q = 0.0;
-        f = 0.0;
+        let mut u = 0.0;
+        let mut g = 0.0;
+        let mut q = 0.0;
+        let mut f = 0.0;
         for n in 0..18 {
             self.bs[n] = 0.0;
         }
 
         // Calculate pure fluid contributions
-        for i in 0..NC_DETAIL {
-            if self.x[i] > 0.0 {
-                xi2 = f64::powi(self.x[i], 2);
-                self.k3 += self.x[i] * self.ki25[i]; // K, U, and G are the sums of a pure fluid contribution and a
-                u += self.x[i] * self.ei25[i]; // binary pair contribution
-                g += self.x[i] * GI[i];
-                q += self.x[i] * QI[i]; // Q and F depend only on the pure fluid parts
+        for (i, x) in self.x.iter().enumerate() {
+            if x > &0.0 {
+                xi2 = x.powi(2);
+                self.k3 += x * self.ki25[i]; // K, U, and G are the sums of a pure fluid contribution and a
+                u += x * self.ei25[i]; // binary pair contribution
+                g += x * GI[i];
+                q += x * QI[i]; // Q and F depend only on the pure fluid parts
                 f += xi2 * FI[i];
 
                 for n in 0..18 {
@@ -1025,15 +1018,15 @@ impl Detail {
                 }
             }
         }
-        self.k3 = f64::powi(self.k3, 2);
-        u = f64::powi(u, 2);
+        self.k3 = self.k3.powi(2);
+        u = u.powi(2);
 
         // Binary pair contributions
-        for i in 0..NC_DETAIL {
-            if self.x[i] > 0.0 {
-                for j in i + 1..NC_DETAIL {
-                    if self.x[j] > 0.0 {
-                        xij = 2.0 * self.x[i] * self.x[j];
+        for (i, xi) in self.x.iter().enumerate() {
+            if xi > &0.0 {
+                for (j, xj) in self.x.iter().enumerate().skip(i + 1) {
+                    if xj > &0.0 {
+                        xij = 2.0 * xi * xj;
                         self.k3 += xij * self.kij5[i][j];
                         u += xij * self.uij5[i][j];
                         g += xij * self.gij5[i][j];
@@ -1045,13 +1038,13 @@ impl Detail {
                 }
             }
         }
-        self.k3 = f64::powf(self.k3, 0.6);
-        u = f64::powf(u, 0.2);
+        self.k3 = self.k3.powf(0.6);
+        u = u.powf(0.2);
 
         // Third virial and higher coefficients
-        q2 = f64::powi(q, 2);
+        let q2 = q.powi(2);
         for n in 12..58 {
-            self.csn[n] = AN[n] * f64::powf(u, UN[n]);
+            self.csn[n] = AN[n] * u.powf(UN[n]);
             if GN[n] == 1 {
                 self.csn[n] *= g;
             }
@@ -1078,8 +1071,6 @@ impl Detail {
         // a0(1) -   partial  (a0)/partial(T) [J/(mol-K)]
         // a0(2) - T*partial^2(a0)/partial(T)^2 [J/(mol-K)]
 
-        let logt: f64;
-        let logd: f64;
         let mut loghyp: f64;
         let mut th0t: f64;
         let mut logxd: f64;
@@ -1096,16 +1087,16 @@ impl Detail {
         self.a0[0] = 0.0;
         self.a0[1] = 0.0;
         self.a0[2] = 0.0;
-        if self.d > EPSILON {
-            logd = f64::ln(self.d);
+        let logd = if self.d > EPSILON {
+            self.d.ln()
         } else {
-            logd = f64::ln(EPSILON);
-        }
-        logt = f64::ln(self.t);
+            EPSILON.ln()
+        };
+        let logt = self.t.ln();
 
-        for i in 0..NC_DETAIL {
-            if self.x[i] > 0.0 {
-                logxd = logd + f64::ln(self.x[i]);
+        for (i, x) in self.x.iter().enumerate() {
+            if x > &0.0 {
+                logxd = logd + x.ln();
                 sumhyp0 = 0.0;
                 sumhyp1 = 0.0;
                 sumhyp2 = 0.0;
@@ -1113,30 +1104,30 @@ impl Detail {
                 for j in 3..7 {
                     if TH0I[i][j] > 0.0 {
                         th0t = TH0I[i][j] / self.t;
-                        ep = f64::exp(th0t);
+                        ep = th0t.exp();
                         em = 1.0 / ep;
                         hsn = (ep - em) / 2.0;
                         hcn = (ep + em) / 2.0;
 
                         if j == 3 || j == 5 {
-                            loghyp = f64::ln(f64::abs(hsn));
+                            loghyp = hsn.abs().ln();
                             sumhyp0 += self.n0i[i][j] * loghyp;
                             sumhyp1 += self.n0i[i][j] * (loghyp - th0t * hcn / hsn);
-                            sumhyp2 += self.n0i[i][j] * f64::powi(th0t / hsn, 2);
+                            sumhyp2 += self.n0i[i][j] * (th0t / hsn).powi(2);
                         } else {
-                            loghyp = f64::ln(f64::abs(hcn));
+                            loghyp = hcn.abs().ln();
                             sumhyp0 += -self.n0i[i][j] * loghyp;
                             sumhyp1 += -self.n0i[i][j] * (loghyp - th0t * hsn / hcn);
-                            sumhyp2 += self.n0i[i][j] * f64::powi(th0t / hcn, 2);
+                            sumhyp2 += self.n0i[i][j] * (th0t / hcn).powi(2);
                         }
                     }
                 }
-                self.a0[0] += self.x[i]
+                self.a0[0] += x
                     * (logxd + self.n0i[i][0] + self.n0i[i][1] / self.t - self.n0i[i][2] * logt
                         + sumhyp0);
                 self.a0[1] +=
-                    self.x[i] * (logxd + self.n0i[i][0] - self.n0i[i][2] * (1.0 + logt) + sumhyp1);
-                self.a0[2] += -self.x[i] * (self.n0i[i][2] + sumhyp2);
+                    x * (logxd + self.n0i[i][0] - self.n0i[i][2] * (1.0 + logt) + sumhyp1);
+                self.a0[2] += -x * (self.n0i[i][2] + sumhyp2);
             }
         }
         self.a0[0] = self.a0[0] * RDETAIL * self.t;
@@ -1167,14 +1158,12 @@ impl Detail {
 
         let mut ckd;
         let mut bkd;
-        let dred;
 
         let mut sum;
         let mut s0;
         let mut s1;
         let mut s2;
         let mut s3;
-        let rt;
 
         let mut sum0: [f64; NTERMS] = [0.0; NTERMS];
         let mut sumb: [f64; NTERMS] = [0.0; NTERMS];
@@ -1193,15 +1182,15 @@ impl Detail {
                 self.ar[i][j] = 0.0;
             }
         }
-        if f64::abs(self.t - self.told) > 0.000_000_1 {
+        if (self.t - self.told).abs() > 0.000_000_1 {
             for (i, item) in UN.iter().enumerate() {
-                self.tun[i] = f64::powf(self.t, -item);
+                self.tun[i] = self.t.powf(-item);
             }
         }
         self.told = self.t;
 
         // Precalculation of common powers and exponents of density
-        dred = self.k3 * self.d;
+        let dred = self.k3 * self.d;
         dknn[0] = 1.0;
 
         for n in 1..10 {
@@ -1210,9 +1199,9 @@ impl Detail {
         expn[0] = 1.0;
 
         for n in 1..5 {
-            expn[n] = f64::exp(-dknn[n]);
+            expn[n] = (-dknn[n]).exp();
         }
-        rt = RDETAIL * self.t;
+        let rt = RDETAIL * self.t;
 
         for n in 0..58 {
             // Contributions to the Helmholtz energy and its derivatives with respect to temperature
@@ -1269,40 +1258,40 @@ impl Detail {
         }
     }
 
-    /// Calculate density as a function of temperature and pressure.  This is an iterative routine that calls PressureDetail
-    /// to find the correct state point.  Generally only 6 iterations at most are required.
+    /// Calculate density as a function of temperature and pressure.
+    ///
+    /// This is an iterative routine that calls PressureDetail
+    /// to find the correct state point. Generally only 6 iterations at most are required.
     /// If the iteration fails to converge, the ideal gas density and an error message are returned.
+    ///
     /// No checks are made to determine the phase boundary, which would have guaranteed that the output is in the gas phase.
     /// It is up to the user to locate the phase boundary, and thus identify the phase of the T and P inputs.
     /// If the state point is 2-phase, the output density will represent a metastable state.
-    pub fn density_detail(&mut self) -> f64 {
-        let plog: f64;
-        let mut vlog: f64;
+    pub fn density(&mut self) -> f64 {
         let mut dpdlv: f64;
         let mut vdiff: f64;
-        let tolr: f64;
         let mut p2: f64;
 
-        if f64::abs(self.p) < EPSILON {
+        if self.p.abs() < EPSILON {
             self.d = 0.0;
             return self.d;
         }
-        tolr = 0.000_000_1;
+        const TOLR: f64 = 0.000_000_1;
         if self.d > -EPSILON {
             self.d = self.p / RDETAIL / self.t; // Ideal gas estimate
         } else {
-            self.d = f64::abs(self.d); // If D<0, then use as initial estimate
+            self.d = self.d.abs(); // If D<0, then use as initial estimate
         }
-        plog = f64::ln(self.p);
-        vlog = -f64::ln(self.d);
+        let plog = self.p.ln();
+        let mut vlog = -self.d.ln();
         for _it in 0..20 {
-            if vlog < -7.0 || vlog > 100.0 {
+            if !(-7.0..=100.0).contains(&vlog) {
                 //ierr = 1; herr = "Calculation failed to converge in DETAIL method, ideal gas density returned.";
                 self.d = self.p / RDETAIL / self.t;
                 return self.d;
             }
-            self.d = f64::exp(-vlog);
-            p2 = self.pressure_detail();
+            self.d = (-vlog).exp();
+            p2 = self.pressure();
             if self.dp_dd_save < EPSILON || p2 < EPSILON {
                 vlog += 0.1;
             } else {
@@ -1310,10 +1299,10 @@ impl Detail {
                 // log(P) as the known variable and log(v) as the unknown property.
                 // See AGA 8 publication for further information.
                 dpdlv = -self.d * self.dp_dd_save; // d(p)/d[log(v)]
-                vdiff = (f64::ln(p2) - plog) * p2 / dpdlv;
+                vdiff = (p2.ln() - plog) * p2 / dpdlv;
                 vlog -= vdiff;
-                if f64::abs(vdiff) < tolr {
-                    self.d = f64::exp(-vlog);
+                if vdiff.abs() < TOLR {
+                    self.d = (-vlog).exp();
                     return self.d; // Iteration converged
                 }
             }
@@ -1323,9 +1312,11 @@ impl Detail {
         self.d
     }
 
-    /// Calculate pressure as a function of temperature and density.  The derivative d(P)/d(D) is also calculated
+    /// Calculate pressure as a function of temperature and density.
+    ///
+    /// The derivative d(P)/d(D) is also calculated
     /// for use in the iterative DensityDetail subroutine (and is only returned as a common variable).
-    pub fn pressure_detail(&mut self) -> f64 {
+    pub fn pressure(&mut self) -> f64 {
         self.x_terms();
         self.alphar(0, 2);
         self.z = 1.0 + self.ar[0][1] / RDETAIL / self.t; // ar(0,1) is the first derivative of alpha(r) with respect to density
@@ -1334,16 +1325,15 @@ impl Detail {
         p
     }
 
-    /// Calculate thermodynamic properties as a function of temperature and density.  Calls are made to the subroutines
-    /// Molarmass, Alpha0Detail, and AlpharDetail.  If the density is not known, call subroutine DensityDetail first
+    /// Calculate thermodynamic properties as a function of temperature and density.
+    ///
+    /// Calls are made to the subroutines
+    /// Molarmass, Alpha0Detail, and AlpharDetail.
+    ///
+    /// If the density is not known, call subroutine DensityDetail first
     /// with the known values of pressure and temperature.
-    pub fn properties_detail(&mut self) {
-        let mm: f64;
-        let a: f64;
-        let r: f64;
-        let rt: f64;
-
-        mm = self.molar_mass_detail();
+    pub fn properties(&mut self) {
+        let mm = self.molar_mass();
         self.x_terms();
 
         // Calculate the ideal gas Helmholtz energy, and its first and second derivatives with respect to temperature.
@@ -1352,26 +1342,25 @@ impl Detail {
         // Calculate the real gas Helmholtz energy, and its derivatives with respect to temperature and/or density.
         self.alphar(2, 3);
 
-        r = RDETAIL;
-        rt = r * self.t;
+        let rt = RDETAIL * self.t;
         self.z = 1.0 + self.ar[0][1] / rt;
         self.p = self.d * rt * self.z;
         self.dp_dd = rt + 2.0 * self.ar[0][1] + self.ar[0][2];
-        self.dp_dt = self.d * r + self.d * self.ar[1][1];
-        a = self.a0[0] + self.ar[0][0];
+        self.dp_dt = self.d * RDETAIL + self.d * self.ar[1][1];
+        let a = self.a0[0] + self.ar[0][0];
         self.s = -self.a0[1] - self.ar[1][0];
         self.u = a + self.t * self.s;
         self.cv = -(self.a0[2] + self.ar[2][0]);
         if self.d > EPSILON {
             self.h = self.u + self.p / self.d;
             self.g = a + self.p / self.d;
-            self.cp = self.cv + self.t * f64::powi(self.dp_dt / self.d, 2) / self.dp_dd;
+            self.cp = self.cv + self.t * (self.dp_dt / self.d).powi(2) / self.dp_dd;
             self.d2p_dd2 = (2.0 * self.ar[0][1] + 4.0 * self.ar[0][2] + self.ar[0][3]) / self.d;
             self.jt = (self.t / self.d * self.dp_dt / self.dp_dd - 1.0) / self.cp / self.d;
         } else {
             self.h = self.u + rt;
             self.g = a + rt;
-            self.cp = self.cv + r;
+            self.cp = self.cv + RDETAIL;
             self.d2p_dd2 = 0.0;
             self.jt = 1.0E+20; //=(dB/dT*T-B)/Cp for an ideal gas, but dB/dT is not calculated here
         }
@@ -1379,7 +1368,7 @@ impl Detail {
         if self.w < 0.0 {
             self.w = 0.0;
         }
-        self.w = f64::sqrt(self.w);
+        self.w = self.w.sqrt();
         self.kappa = self.w * self.w * mm / (rt * 1000.0 * self.z);
         self.d2p_dtd = 0.0;
     }
